==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Sections/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Printervenlig side");
define("_PREVIOUS","Forrige side");
define("_NEXT","Nste side");
define("_COMESFROM","Denne artikel kommer fra");
define("_THEURL","Internetadressen til denne artikel er:");
define("_SECWELCOME","Velkommen til andre sektioner hos");
define("_YOUCANFIND","Her kan du finde interssante artikler, som ikke hrer ind under hovedsektionen.");
define("_THISISSEC","Dette er sektionen");
define("_FOLLOWINGART","Flgende artikler er publiceret i denne sektion.");
define("_SECRETURN","Tilbage til sektionsoversigt");
define("_TOTALWORDS","antal ord i denne tekst");
define("_BACKTO","Tilbage til");
define("_SECINDEX","Sektionsoversigt");
define("_PAGE","Side");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Sections/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Printervenlig side");
define("_PREVIOUS","Forrige side");
define("_NEXT","Nste side");
define("_COMESFROM","Denne artikel kommer fra");
define("_THEURL","Internetadressen til denne artikel er:");
define("_SECWELCOME","Velkommen til andre sektioner hos");
define("_YOUCANFIND","Her kan du finde interssante artikler, som ikke hrer ind under hovedsektionen.");
define("_THISISSEC","Dette er sektionen");
define("_FOLLOWINGART","Flgende artikler er publiceret i denne sektion.");
define("_SECRETURN","Tilbage til sektionsoversigt");
define("_TOTALWORDS","antal ord i denne tekst");
define("_BACKTO","Tilbage til");
define("_SECINDEX","Sektionsoversigt");
define("_PAGE","Side");

?>
